@@ -5,7 +5,7 @@ import json
 import os
 import shutil
 import time
-from typing import Any, Optional
+from typing import Any
 
 
 def openWindowsFolder(folder: str):
@@ -258,7 +258,7 @@ def strByTimestamp(timestamp: float = time.time(), fmt: str = _DEFAULT_FMT):
     return time.strftime(fmt, ary)
 
 
-def hold(msg: Optional[str] = None, showInput: bool = True, *exitValueList: str):
+def hold(msg: str | None = None, showInput: bool = True, *exitValueList: str):
     msg = msg or "测试暂停，输入exit可以退出"
     exitValueList = exitValueList or ("exit",)
     inputFunc = showInput and input or getpass.getpass
@@ -308,6 +308,10 @@ def xToInt(value: str):
     return int(value, len(_xPar))
 
 
+def printTimestamp(timestamp: int | float):
+    print(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(timestamp)))
+
+
 # def scrapy(urlList, parseFun, extendSettings=None):
 
 #     from scrapy.crawler import CrawlerProcess
