@@ -1,11 +1,11 @@
 import os
-from typing import Callable, Optional
+from typing import Callable
 from zipfile import ZIP_DEFLATED, ZipFile
 
 from . import getAllFileAndFolderList, makeFolder
 
 
-def zipFile(toFile: str, fileFolderOrAry: str | list[str], rename: Optional[Callable[[str], str]] = None):
+def zipFile(toFile: str, fileFolderOrAry: str | list[str], rename: Callable[[str], str] | None = None):
     makeFolder(os.path.dirname(toFile))
     fileList: list[str] = []
     if type(fileFolderOrAry) is list:
@@ -19,7 +19,7 @@ def zipFile(toFile: str, fileFolderOrAry: str | list[str], rename: Optional[Call
             f.write(file, fname)
 
 
-def zipFileForFolder(toFile: str, folder: str, rename: Optional[Callable[[str], str]] = None, filterFun: Optional[Callable[[str], bool]] = None):
+def zipFileForFolder(toFile: str, folder: str, rename: Callable[[str], str] | None = None, filterFun: Callable[[str], bool] | None = None):
     if not folder.endswith(os.path.sep):
         folder += os.path.sep
     rename = rename or (lambda x: x[len(folder):])
@@ -29,7 +29,7 @@ def zipFileForFolder(toFile: str, folder: str, rename: Optional[Callable[[str],
     zipFile(toFile, ary, rename)
 
 
-def zipFileExtract(file: str, toFolder: Optional[str] = None):
+def zipFileExtract(file: str, toFolder: str | None = None):
     toFolder = toFolder or os.path.dirname(file)
     with ZipFile(file) as f:
         for subFile in sorted(f.namelist()):
